@@ -8,6 +8,7 @@ from euphorie.client.country import IClientCountry
 from euphorie.client.model import get_current_account
 from euphorie.client.sector import IClientSector
 from euphorie.content.survey import ISurvey
+from euphorie.content.utils import getRegionTitle
 from logging import getLogger
 from plone import api
 from plone.memoize.view import memoize
@@ -72,7 +73,9 @@ class Node(NodeMixin):
 
 class SurveyTemplatesMixin(object):
     # switch from radio buttons to dropdown above this number of tools
-    tools_threshold = 12
+    # Note: since there's a CSS glitch with displaying radio buttons, we always
+    # show the the dropdown
+    tools_threshold = 0
 
     # Here, we assemble the list of available tools for starting a new session
 
@@ -141,7 +144,7 @@ class SurveyTemplatesMixin(object):
                     categories = [None]
                 for category in categories:
                     survey_items.append((category, survey, id))
-        return sorted(survey_items, key=lambda x: (x[0] or "", x[1].title))
+        return sorted(survey_items, key=lambda x: (x[0], x[1].title))
 
 
 class SessionsView(BrowserView, SurveyTemplatesMixin):
@@ -354,6 +357,122 @@ class SessionBrowserNavigator(BrowserView):
         return False
 
 
+class Assessments(BrowserView):
+    @property
+    @memoize
+    def webhelpers(self):
+        return api.content.get_view("webhelpers", self.context, self.request)
+
+    @property
+    @memoize
+    def sessions(self):
+        searchable_text = self.request.get("SearchableText", None)
+        if searchable_text and "%" not in searchable_text:
+            searchable_text = "%{}%".format(searchable_text)
+        return self.webhelpers.get_sessions_query(
+            context=self.context,
+            searchable_text=searchable_text,
+            include_archived=True,
+        ).all()
+
+
+class Surveys(BrowserView, SurveyTemplatesMixin):
+    @property
+    @memoize
+    def webhelpers(self):
+        return api.content.get_view("webhelpers", self.context, self.request)
+
+    def get_filters(self):
+        filters = {}
+        get = self.request.form.get
+
+        client_path = "/".join(self.request.client.getPhysicalPath())
+        path = "/".join((client_path, self.country))
+        sector = get("sector")
+        if sector:
+            path = "/".join((path, sector))
+        filters["path"] = path
+
+        language = get("Language")
+        if language:
+            filters["Language"] = language
+
+        sort_on = get("sort_on", "created")
+        filters["sort_on"] = sort_on
+        if sort_on == "created":
+            filters["sort_order"] = "reverse"
+
+        searchable_text = get("SearchableText")
+        if searchable_text:
+            filters["SearchableText"] = searchable_text
+
+        return filters
+
+    @property
+    @memoize
+    def country(self):
+        return self.request.form.get("country", self.context.getId())
+
+    @property
+    @memoize
+    def countries(self):
+        return sorted(
+            [
+                {
+                    "id": country.getId(),
+                    "Title": getRegionTitle(self.request, country.getId()),
+                }
+                for country in self.request.client.values()
+                if (IClientCountry.providedBy(country) and len(country.objectIds()))
+            ],
+            key=lambda co: "0" if co["id"] == "eu" else co["Title"],
+        )
+
+    @property
+    @memoize
+    def sectors(self):
+        country_obj = self.request.client.restrictedTraverse(self.country)
+        return [
+            sector
+            for sector in aq_inner(country_obj).values()
+            if IClientSector.providedBy(sector)
+        ]
+
+    @property
+    @memoize
+    def tools(self):
+        filters = self.get_filters()
+        tools = [
+            (None, survey.getObject(), survey.getId)
+            for survey in api.content.find(
+                object_provides="euphorie.content.survey.ISurvey", **filters
+            )
+        ]
+        # We must filter out tools marked as obsolete or preview
+        return [
+            record
+            for record in tools
+            if (
+                not getattr(record[1], "preview", None)
+                and not getattr(record[1], "obsolete", None)
+            )
+        ]
+
+    @property
+    @memoize
+    def languages(self):
+        return sorted(
+            [
+                {"code": code, "name": self.webhelpers.getNameForLanguageCode(code)}
+                for code in api.portal.get_tool("portal_catalog").uniqueValuesFor(
+                    "Language"
+                )
+                if code and code != "None"
+            ],
+            key=lambda lang: lang["code"],
+        )
+
+
 class PortletBase(BrowserView):
     @property
     @memoize
@@ -414,14 +533,18 @@ class MyRAsPortlet(PortletBase):
     @memoize
     def sessions(self):
         """We want the archived sessions"""
-        return self.webhelpers.get_sessions_query(
-            context=self.context, include_archived=not self.hide_archived
-        ).all()
+        return (
+            self.webhelpers.get_sessions_query(
+                context=self.context, include_archived=not self.hide_archived
+            )
+            .limit(5)
+            .all()
+        )
 
     @property
     def label_start_session(self):
         label = api.portal.translate(
-            _(u"link_start_session", default=u"start a new session")
+            _(u"link_start_session", default=u"Start a new risk assessment")
         )
         return capitalize(label)
 
