@@ -34,7 +34,7 @@ class ResetPasswordFormSchema(model.Schema):
         title=_(u"label_new_password", default=u"Desired password"),
     )
     new_password_confirmation = schema.Password(
-        title=_(u"label_new_password", default=u"Confirm your password"),
+        title=_(u"label_confirm_password", default=u"Confirm your password"),
     )
 
     @invariant
@@ -89,6 +89,10 @@ class ResetPasswordRequest(BaseForm):
             u"with the instructions to reset your password."
         ),
     )
+    button_label = _(
+        u"label_send_password_reminder",
+        default="Send password reminder",
+    )
 
     email_template = ViewPageTemplateFile("templates/password_recovery_email.pt")
 
@@ -163,15 +167,19 @@ class ResetPasswordRequest(BaseForm):
         data, error = self.extractData()
         if error:
             return
-        if not self.send_mail(data["email"]):
+        email = data.get("email")
+        if not self.send_mail(email):
             return
         msg = _(
-            u"An email will be sent "
-            u"if we can find an account for the inserted email address"
+            "message_password_recovery_email_sent",
+            default=u"An email will be sent to ${email} "
+            u"if we can find an account for this email address. Please use the "
+            u"link inside the e-mail to reset your password.",
+            mapping={"email": email},
         )
         redir_url = self.request.get("came_from") or self.context.absolute_url()
         if not redir_url.endswith("login"):
-            redir_url = "{0}/@@login?{1}".format(
+            redir_url = "{0}/@@login?{1}#login".format(
                 redir_url, urlencode({"came_from": redir_url})
             )
         self.redirect(redir_url, msg)
@@ -201,6 +209,7 @@ class ResetPasswordForm(BaseForm):
         u"description_reset_password_form",
         default=u"",
     )
+    button_label = _("Save changes")
 
     def publishTraverse(self, request, name):
         return self
@@ -217,7 +226,7 @@ class ResetPasswordForm(BaseForm):
         if errors:
             for err in errors:
                 if isinstance(err.error, Exception):
-                    err.message = _(
+                    self.error = _(
                         "error_password_mismatch", default=u"Passwords do not match"
                     )
             return
@@ -228,24 +237,29 @@ class ResetPasswordForm(BaseForm):
         try:
             ppr.verifyKey(key)
         except InvalidRequestError:
-            return self.redirect(
-                self.context.absolute_url() + "/@@reset_password_request",
-                msg=_("Invalid security token, try to request a new one"),
-                msg_type="error",
-            )
+            self.error = _("Invalid security token, try to request a new one")
+            return
+
+        login_view = api.content.get_view(
+            name="login",
+            context=self.context,
+            request=self.request,
+        )
+        error = login_view.check_password_policy(data["new_password"])
+        if error:
+            self.error = error
+            return
 
         account_id = ppr._requests.get(key)[0]
         account = Session().query(Account).filter(Account.id == account_id).one()
         account.password = data["new_password"]
         current_url = self.context.absolute_url()
         return self.redirect(
-            "{}/@@login_form?{}".format(
-                current_url, urlencode(dict(came_from=current_url))
-            ),
+            "{}/@@login?{}".format(current_url, urlencode(dict(came_from=current_url))),
             msg=_("Your password was successfully changed."),
         )
 
-    @button.buttonAndHandler(_(u"Save changes"))
+    @button.buttonAndHandler(_(u"Save"))
     def save_handler(self, action):
         """Check if the security token is correct and if it is
         change the account password with the provided value
