@@ -22,6 +22,7 @@ from euphorie.client.sector import IClientSector
 from euphorie.client.update import wasSurveyUpdated
 from euphorie.client.utils import getSecret
 from euphorie.content.survey import ISurvey
+from euphorie.content.utils import getRegionTitle
 from euphorie.content.utils import StripMarkup
 from euphorie.ghost import PathGhost
 from json import dumps
@@ -29,23 +30,24 @@ from logging import getLogger
 from os import path
 from pkg_resources import resource_listdir
 from plone import api
+from plone.i18n.interfaces import ILanguageUtility
 from plone.i18n.normalizer import idnormalizer
 from plone.memoize import forever
 from plone.memoize.instance import memoize
 from plone.memoize.view import memoize_contextless
-from plone.registry.interfaces import IRegistry
 from plonetheme.nuplone.utils import isAnonymous
 from Products.CMFCore.interfaces import ISiteRoot
 from Products.CMFCore.utils import getToolByName
-from Products.CMFPlone.interfaces import ISecuritySchema
 from Products.Five import BrowserView
 from Products.statusmessages.interfaces import IStatusMessage
 from six.moves.urllib.parse import urlencode
+from user_agents import parse
 from ZODB.POSException import POSKeyError
 from zope.component import getMultiAdapter
 from zope.component import getUtility
 from zope.component.hooks import getSite
 from zope.deprecation import deprecate
+from zope.i18n import translate
 from zope.i18nmessageid import MessageFactory
 
 
@@ -145,13 +147,6 @@ class WebHelpers(BrowserView):
             "euphorie.allow_guest_accounts", default=False
         )
 
-    @property
-    @memoize
-    def allow_self_registration(self):
-        registry = getUtility(IRegistry)
-        security_settings = registry.forInterface(ISecuritySchema, prefix="plone")
-        return security_settings.enable_self_reg
-
     @property
     @memoize
     def use_involve_phase(self):
@@ -298,8 +293,9 @@ class WebHelpers(BrowserView):
         session.completion_percentage = completion_percentage
         return completion_percentage
 
-    def get_progress_indicator_title(self):
-        completion_percentage = self.traversed_session.session.completion_percentage
+    def get_progress_indicator_title(self, completion_percentage=None):
+        if completion_percentage is None and self.traversed_session is not None:
+            completion_percentage = self.traversed_session.session.completion_percentage
         title = _(
             "progress_indicator_title",
             default=u"${completion_percentage}% Complete",
@@ -390,6 +386,18 @@ class WebHelpers(BrowserView):
         lang = lt.getPreferredLanguage()
         return lang
 
+    @memoize_contextless
+    def getNameForLanguageCode(self, langCode):
+        lang_util = getUtility(ILanguageUtility)
+        info = lang_util.getAvailableLanguageInformation().get(langCode, None)
+        if info is not None:
+            return info.get("native", info.get("name", None))
+        return None
+
+    @memoize
+    def getTranslatedCountryName(self, country_id):
+        return getRegionTitle(self.request, country_id)
+
     @property
     @forever.memoize
     def available_help_languages(self):
@@ -602,6 +610,12 @@ class WebHelpers(BrowserView):
             head, tail = path.split(head)
         return ""
 
+    def get_dashboard_tab(self):
+        head, tail = path.split(self.request.PATH_INFO)
+        if tail in ["surveys", "assessments"]:
+            return tail
+        return "dashboard"
+
     @property
     def came_from_param(self):
         if self.came_from:
@@ -772,11 +786,8 @@ class WebHelpers(BrowserView):
     def timezoned_date(self, mydate=None):
         if mydate is None:
             return None
-        # If the date already has a timezone, don't touch it
-        if mydate.tzinfo is not None:
-            return mydate
-        local_tz = tz.gettz(self.server_timezone)
-        return mydate.replace(tzinfo=local_tz)
+        utc = tz.gettz(self.server_timezone)
+        return mydate.replace(tzinfo=utc)
 
     @property
     @memoize
@@ -1061,5 +1072,52 @@ class WebHelpers(BrowserView):
             query = query.order_by(table.modified.desc(), table.title)
         return query
 
+    @memoize
+    def is_outdated_browser(self):
+        ua_string = self.request.get("HTTP_USER_AGENT", "")
+        ua = parse(ua_string)
+        return ua.browser.family == "IE"
+
+    @property
+    def pat_validation_messages(self):
+        lang = getattr(self.request, "LANGUAGE", "en")
+        if "-" in lang:
+            elems = lang.split("-")
+            lang = "{0}_{1}".format(elems[0], elems[1].upper())
+        messages = {
+            "message-date": translate(
+                _("error_validation_date", default="This value must be a valid date"),
+                target_language=lang,
+            ),
+            "message-datetime": translate(
+                _(
+                    "error_validation_datetime",
+                    default="This value must be a valid date and time",
+                ),
+                target_language=lang,
+            ),
+            "message-email": translate(
+                _(
+                    "error_validation_email",
+                    default="This value must be a valid email address",
+                ),
+                target_language=lang,
+            ),
+            "message-number": translate(
+                _("error_validation_number", default="This value must be a number"),
+                target_language=lang,
+            ),
+            "message-required": translate(
+                _("message_field_required", default="Please fill out this field."),
+                target_language=lang,
+            ),
+        }
+        return "; ".join(
+            [
+                "{key}: {value}".format(key=key, value=value)
+                for key, value in messages.items()
+            ]
+        )
+
     def __call__(self):
         return self
