@@ -1,5 +1,5 @@
 # coding=utf-8
-from euphorie.client import publish
+from euphorie.client.browser import publish
 from euphorie.testing import EuphorieFunctionalTestCase
 from plone.dexterity.utils import createContentInContainer
 
