@@ -54,7 +54,7 @@ def randomString(length=16):
 
 
 def get_translated_custom_risks_title(request):
-    return api.portal.translate(_("title_other_risks", default=u"Added risks (by you)"))
+    return api.portal.translate(_("Custom risks", default=u"Custom risks"))
 
 
 def HasText(html):
@@ -136,8 +136,7 @@ def remove_empty_modules(nodes):
         for i in range(0, len(nodes)):
             node = nodes[i]
             inserted = False
-            keys = list(tree)
-            for k in keys:
+            for k in tree.keys():
                 if node.path.startswith(k[0]):
                     if tree[k]:
                         grow(tree[k], [node])
@@ -157,8 +156,7 @@ def remove_empty_modules(nodes):
                 del tree[k]
 
     def flatten(tree):
-        keys = list(tree)
-        for k in keys:
+        for k in tree.keys():
             ids.append(k[2])
             flatten(tree[k])
 
