@@ -22,58 +22,51 @@ from euphorie.content.survey import ISurvey
 from euphorie.content.surveygroup import ISurveyGroup
 from euphorie.content.user import IUser
 from euphorie.content.user import UserProvider
-from five import grok
-from plone import api
 from plone.app.dexterity.behaviors.metadata import IBasic
 from plone.app.layout.navigation.interfaces import INavigationRoot
+from plone.autoform import directives
 from plone.dexterity.content import Container
-from plone.directives import dexterity
-from plone.directives import form
 from plone.indexer import indexer
 from plone.namedfile import field as filefield
+from plone.supermodel import model
 from plone.uuid.interfaces import IAttributeUUID
-from plonetheme.nuplone.skin import actions
-from plonetheme.nuplone.skin.interfaces import NuPloneSkin
 from plonetheme.nuplone.utils import checkPermission
-from plonetheme.nuplone.utils import getPortal
 from Products.CMFCore.utils import getToolByName
 from Products.CMFEditions.Permissions import AccessPreviousVersions
-from Products.statusmessages.interfaces import IStatusMessage
 from zope import schema
-from zope.interface import implements
+from zope.component import adapter
+from zope.interface import implementer
 
 import datetime
 import logging
-import zExceptions
 
 
 log = logging.getLogger(__name__)
-grok.templatedir("templates")
 
 
-class ISector(form.Schema, IUser, IBasic):
+class ISector(model.Schema, IUser, IBasic):
     """Sector object.
 
     A sector is a national organisation for a specific type of
     industry.
     """
 
-    form.order_before(title="*")
-    dexterity.write_permission(title="euphorie.content.ManageCountry")
+    directives.order_before(title="*")
+    directives.write_permission(title="euphorie.content.ManageCountry")
 
-    form.order_after(login="title")
-    dexterity.write_permission(login="euphorie.content.ManageCountry")
+    directives.order_after(login="title")
+    directives.write_permission(login="euphorie.content.ManageCountry")
 
-    form.order_before(password="description")
+    directives.order_before(password="description")
 
-    form.order_after(locked="password")
-    dexterity.write_permission(locked="euphorie.content.ManageCountry")
+    directives.order_after(locked="password")
+    directives.write_permission(locked="euphorie.content.ManageCountry")
 
     contact_name = schema.TextLine(
         title=_("label_contact_name", default=u"Contact name"), required=True
     )
 
-    form.order_after(contact_email="contact_name")
+    directives.order_after(contact_email="contact_name")
 
     logo = filefield.NamedBlobImage(
         title=_("label_logo", default=u"Logo"),
@@ -87,6 +80,7 @@ class ISector(form.Schema, IUser, IBasic):
     )
 
 
+@implementer(ISector, INavigationRoot, IAttributeUUID)
 class Sector(Container):
     """A sector of industry.
 
@@ -95,7 +89,6 @@ class Sector(Container):
     """
 
     portal_type = "euphorie.clientsector"
-    implements(ISector, INavigationRoot, IAttributeUUID)
 
     locked = False
 
@@ -111,16 +104,17 @@ def SearchableTextIndexer(obj):
     )
 
 
-class SectorLocalRoleProvider(grok.Adapter):
+@adapter(ISector)
+@implementer(ILocalRoleProvider)
+class SectorLocalRoleProvider(object):
     """`borg.localrole` provider for :obj:`ISector` instances.
 
     This local role provider gives the sector user itself the
     `Sector` local role.
     """
 
-    grok.context(ISector)
-    grok.implements(ILocalRoleProvider)
-    grok.name("euphorie.sector")
+    def __init__(self, context):
+        self.context = context
 
     def getRoles(self, principal_id):
         mt = getToolByName(self.context, "membrane_tool")
@@ -223,110 +217,3 @@ def getSurveys(context):
         result.append(info)
     result.sort(key=lambda g: g["title"].lower())
     return result
-
-
-class View(grok.View):
-    grok.context(ISector)
-    grok.require("zope2.View")
-    grok.layer(NuPloneSkin)
-    grok.template("sector_view")
-    grok.name("nuplone-view")
-
-    def update(self):
-        self.add_survey_url = (
-            "%s/++add++euphorie.surveygroup" % aq_inner(self.context).absolute_url()
-        )
-        self.surveys = getSurveys(self.context)
-        permission = "Euphorie: Add new RIE Content"
-        user = api.user.get_current()
-        self.can_add = api.user.has_permission(permission, user=user, obj=self.context)
-        super(View, self).update()
-
-
-class Delete(actions.Delete):
-    """Only delete the sector if it doesn't have any published surveys."""
-
-    grok.context(ISector)
-
-    def verify(self, container, context):
-        if not checkPermission(container, "Delete objects"):
-            raise zExceptions.Unauthorized
-
-        flash = IStatusMessage(self.request).addStatusMessage
-        sector = context
-        country = container
-        client = getPortal(container).client
-
-        if country.id not in client:
-            return True
-
-        cl_country = client[country.id]
-        if sector.id not in cl_country:
-            return True
-
-        # Look for any published surveys in the client sector, and prevent
-        # deletion if any are found
-        cl_sector = cl_country[sector.id]
-        surveys = [s for s in cl_sector.values() if s.id != "preview"]
-        if surveys:
-            flash(
-                _(
-                    "message_not_delete_published_sector",
-                    default=u"You can not delete a sector that contains published "
-                    u"OiRA Tools.",
-                ),
-                "error",
-            )
-            self.request.response.redirect(context.absolute_url())
-            return False
-        return True
-
-
-class ColourPreview(grok.View):
-    grok.context(ISector)
-    grok.require("cmf.ModifyPortalContent")
-    grok.layer(NuPloneSkin)
-    grok.name("colour-preview")
-    grok.template("colour-preview")
-
-    def default_title(self):
-        from .. import MessageFactory as _
-
-        return _("title_tool", default=u"OiRA - Online interactive Risk Assessment")
-
-
-class Settings(form.SchemaEditForm):
-    grok.context(ISector)
-    grok.require("cmf.ModifyPortalContent")
-    grok.layer(NuPloneSkin)
-    grok.name("edit")
-    grok.template("settings")
-
-    schema = ISector
-    default_fieldset_label = None
-    formErrorsMessage = u"Please correct the indicated errors."
-
-    def extractData(self):
-        self.fields = self.fields.omit("title", "login")
-        if "title" in self.widgets:
-            del self.widgets["title"]
-        if "login" in self.widgets:
-            del self.widgets["login"]
-        return super(Settings, self).extractData()
-
-
-class VersionCommand(grok.View):
-    grok.context(ISector)
-    grok.require("zope2.View")
-    grok.layer(NuPloneSkin)
-    grok.name("version-command")
-
-    def render(self):
-        action = self.request.get("action")
-        if action == "new":
-            sector = aq_inner(self.context)
-            self.request.response.redirect(
-                "%s/++add++euphorie.surveygroup" % sector.absolute_url()
-            )
-        else:
-            log.error("Invalid version command action: %r", action)
